@@ -1,13 +1,23 @@
 from django.conf import settings
 from django.utils.translation import gettext_lazy as _
 
-ACTIVE_FOR_SALE_STANDARD = 0
-ACTIVE_FOR_SALE_YES = 2
-ACTIVE_FOR_SALE_NO = 3
-ACTIVE_FOR_SALE_CHOICES = [
-    (ACTIVE_FOR_SALE_STANDARD, _(u"Standard")),
-    (ACTIVE_FOR_SALE_YES, _(u"Yes")),
-    (ACTIVE_FOR_SALE_NO, _(u"No")),
+QUANTITY_FIELD_INTEGER = 0
+QUANTITY_FIELD_DECIMAL_1 = 1
+QUANTITY_FIELD_DECIMAL_2 = 2
+
+QUANTITY_FIELD_TYPES = [
+    (QUANTITY_FIELD_INTEGER, _(u"Integer")),
+    (QUANTITY_FIELD_DECIMAL_1, _(u"Decimal 0.1")),
+    (QUANTITY_FIELD_DECIMAL_2, _(u"Decimal 0.01")),
+]
+
+CHOICES_STANDARD = 0
+CHOICES_YES = 2
+CHOICES_NO = 3
+CHOICES = [
+    (CHOICES_STANDARD, _(u"Standard")),
+    (CHOICES_YES, _(u"Yes")),
+    (CHOICES_NO, _(u"No")),
 ]
 
 STANDARD_PRODUCT = "0"
@@ -35,6 +45,16 @@ PRODUCT_TYPE_FORM_CHOICES = [
     (CONFIGURABLE_PRODUCT, _(u"Configurable product")),
 ]
 
+CATEGORY_VARIANT_DEFAULT = -1
+CATEGORY_VARIANT_CHEAPEST_PRICE = -2
+CATEGORY_VARIANT_CHEAPEST_BASE_PRICE = -3
+CATEGORY_VARIANT_CHEAPEST_PRICES = -4
+CATEGORY_VARIANT_CHOICES = [
+    (CATEGORY_VARIANT_DEFAULT, _(u"Default")),
+    (CATEGORY_VARIANT_CHEAPEST_PRICE, _(u"Cheapest price")),
+    (CATEGORY_VARIANT_CHEAPEST_BASE_PRICE, _(u"Cheapest base price")),
+    (CATEGORY_VARIANT_CHEAPEST_PRICES, _(u"Cheapest prices")),
+]
 
 LIST = 0
 SELECT = 1
