@@ -3,6 +3,7 @@ from datetime import datetime
 
 # django imports
 from django import forms
+from django.conf import settings
 from django.forms.util import ErrorList
 from django.utils.translation import ugettext_lazy as _
 
@@ -18,13 +19,15 @@ class OnePageCheckoutForm(forms.Form):
     """
     invoice_firstname = forms.CharField(label=_(u"First Name"), max_length=50)
     invoice_lastname = forms.CharField(label=_(u"Last Name"), max_length=50)
-    invoice_phone = forms.CharField(label=_(u"Invoice Phone"), max_length=20, required=False)
+    invoice_phone = forms.CharField(label=_(u"Invoice Phone"), required=getattr(settings, "LFS_INVOICE_PHONE_REQUIRED", False), max_length=20)
     invoice_email = forms.EmailField(label=_(u"Invoice E-mail"), required=False, max_length=50)
+    invoice_company_name = forms.CharField(label=_(u"Company name"), required=getattr(settings, "LFS_INVOICE_COMPANY_NAME_REQUIRED", False), max_length=50)
 
     shipping_firstname = forms.CharField(label=_(u"First Name"), required=False, max_length=50)
     shipping_lastname = forms.CharField(label=_(u"Last Name"), required=False, max_length=50)
     shipping_phone = forms.CharField(label=_(u"Shipping Phone"), required=False, max_length=20)
     shipping_email = forms.EmailField(label=_(u"Shipping E-mail"), required=False, max_length=50)
+    shipping_company_name = forms.CharField(label=_(u"Company name"), required=False, max_length=50)
 
     requested_delivery_date = forms.DateField(label=_(u"Requested Delivery Date"), required=False)
 
@@ -58,16 +61,29 @@ class OnePageCheckoutForm(forms.Form):
         msg = _(u"This field is required.")
 
         if self.data.get("is_anonymous") == "1" and \
-           not self.cleaned_data.get("invoice_email"):
+           getattr(settings, "LFS_INVOICE_EMAIL_REQUIRED") and \
+           self.cleaned_data.get("invoice_email") == "":
             self._errors["invoice_email"] = ErrorList([msg])
 
         if not self.cleaned_data.get("no_shipping"):
-            if self.cleaned_data.get("shipping_firstname", "") == "":
+            if self.cleaned_data.get("shipping_firstname") == "":
                 self._errors["shipping_firstname"] = ErrorList([msg])
 
-            if self.cleaned_data.get("shipping_lastname", "") == "":
+            if self.cleaned_data.get("shipping_lastname") == "":
                 self._errors["shipping_lastname"] = ErrorList([msg])
 
+            if getattr(settings, "LFS_SHIPPING_COMPANY_NAME_REQUIRED", False):
+                if self.cleaned_data.get("shipping_company_name") == "":
+                    self._errors["shipping_company_name"] = ErrorList([msg])
+
+            if getattr(settings, "LFS_SHIPPING_PHONE_REQUIRED", False):
+                if self.cleaned_data.get("shipping_phone") == "":
+                    self._errors["shipping_phone"] = ErrorList([msg])
+
+            if getattr(settings, "LFS_SHIPPING_EMAIL_REQUIRED", False):
+                if self.cleaned_data.get("shipping_email") == "":
+                    self._errors["shipping_email"] = ErrorList([msg])
+
         # check that shipping country is in the shops shipping countries list
         shop = get_default_shop()
         shipping_countries = shop.shipping_countries.all()
@@ -76,15 +92,15 @@ class OnePageCheckoutForm(forms.Form):
             shipping_country_code = self.data.get("shipping-country", None)
             if shipping_country_code:
                 shipping_country = Country.objects.get(code=shipping_country_code.lower())
+            if shipping_country:
+                if shipping_country not in shipping_countries:
+                    msg = _(u"Invalid shipping country.")
+                    #self._errors["all"] = ErrorList([msg])
+                    raise forms.ValidationError("Invalid Shipping Country")
         else:
             shipping_country_code = self.data.get("invoice-country", None)
             if shipping_country_code:
                 shipping_country = Country.objects.get(code=shipping_country_code.lower())
-        if shipping_country:
-            if shipping_country not in shipping_countries:
-                msg = _(u"Invalid shipping country.")
-                #self._errors["all"] = ErrorList([msg])
-                raise forms.ValidationError("Invalid Shipping Country")
 
         # Check data of selected payment method
         payment_method_id = self.data.get("payment_method")
