@@ -17,14 +17,14 @@ import lfs.catalog.utils
 import lfs.utils.misc
 from lfs.caching.utils import lfs_get_object_or_404
 from lfs.catalog.models import Category
+from lfs.catalog.settings import CONFIGURABLE_PRODUCT
+from lfs.catalog.settings import CATEGORY_VARIANT_CHEAPEST_PRICES
 from lfs.catalog.settings import PRODUCT_WITH_VARIANTS
 from lfs.catalog.settings import STANDARD_PRODUCT
-from lfs.catalog.settings import CONFIGURABLE_PRODUCT
 from lfs.catalog.models import Product
 from lfs.catalog.models import PropertyOption
 from lfs.catalog.settings import PRODUCT_TYPE_LOOKUP
 import lfs.core.utils
-from lfs.core.models import Shop
 from lfs.core.models import Action
 from lfs.page.models import Page
 from lfs.shipping import utils as shipping_utils
@@ -44,7 +44,7 @@ def google_analytics_tracking(context):
     """Returns google analytics tracking code which has been entered to the
     shop.
     """
-    shop = lfs_get_object_or_404(Shop, pk=1)
+    shop = lfs.core.utils.get_default_shop(context.get("request"))
     return {
         "ga_site_tracking": shop.ga_site_tracking,
         "google_analytics_id": shop.google_analytics_id,
@@ -58,7 +58,7 @@ def google_analytics_ecommerce(context, clear_session=True):
     """
     request = context.get("request")
     order = request.session.get("order")
-    shop = lfs_get_object_or_404(Shop, pk=1)
+    shop = lfs.core.utils.get_default_shop(request)
 
     # The order is removed from the session. It has been added after the order
     # has been payed within the checkout process. See order.utils for more.
@@ -80,12 +80,12 @@ def _get_shipping(context, product):
     if product.is_deliverable() == False:
         return {
             "deliverable": False,
-            "delivery_time": shipping_utils.get_product_delivery_time(request, product.slug)
+            "delivery_time": shipping_utils.get_product_delivery_time(request, product)
         }
     else:
         return {
             "deliverable": True,
-            "delivery_time": shipping_utils.get_product_delivery_time(request, product.slug)
+            "delivery_time": shipping_utils.get_product_delivery_time(request, product)
         }
 
 
@@ -160,7 +160,7 @@ def breadcrumbs(context, obj):
         objects = []
         objects.append({
             "name": _(u"Information"),
-            "url": reverse("lfs_pages")}),
+            "url": reverse("lfs_pages")})
         objects.append({"name": obj.title})
 
         result = {
@@ -260,6 +260,9 @@ def product_navigation(context, product):
 
 
 class ActionsNode(Node):
+    """
+    Node for do_actions.
+    """
     def __init__(self, group_name):
         self.group_name = group_name
 
@@ -270,17 +273,53 @@ class ActionsNode(Node):
 
 
 def do_actions(parser, token):
-    """Returns the actions for the group with the given id.
+    """
+    Returns the actions for the group with the given id.
     """
     bits = token.contents.split()
     len_bits = len(bits)
     if len_bits != 2:
         raise TemplateSyntaxError(_('%s tag needs group id as argument') % bits[0])
-
     return ActionsNode(bits[1])
 register.tag('actions', do_actions)
 
 
+class CheapestVariantNode(Node):
+    """
+    Node for do_cheapest_variant.
+    """
+    def __init__(self, product_id):
+        self.product_id = template.Variable(product_id)
+
+    def render(self, context):
+        product_id = self.product_id.resolve(context)
+        request = context.get("request")
+        cheapest_variant = None
+        min_price = None
+        for variant in Product.objects.filter(parent__id=product_id):
+            price = variant.get_price_gross(request)
+            if price == 0:
+                continue
+            if (min_price is None) or (price < min_price):
+                cheapest_variant = variant
+                min_price = price
+
+        context["cheapest_variant"] = cheapest_variant
+        return ""
+
+
+def do_cheapest_variant(parser, token):
+    """
+    Returns the cheapest variant for the product with given id.
+    """
+    bits = token.contents.split()
+    len_bits = len(bits)
+    if len_bits != 2:
+        raise TemplateSyntaxError('%s tag needs product id as argument' % bits[0])
+    return CheapestVariantNode(bits[1])
+register.tag('cheapest_variant', do_cheapest_variant)
+
+
 @register.inclusion_tag('lfs/shop/tabs.html', takes_context=True)
 def tabs(context, obj=None):
     """
@@ -431,7 +470,7 @@ def get_slug_from_request(request):
 
 
 @register.filter
-def currency(value, grouping=True):
+def currency(value, request=None, grouping=True):
     """
     e.g.
     import locale
@@ -442,8 +481,12 @@ def currency(value, grouping=True):
     if not value:
         value = 0.0
 
-    shop = lfs.core.utils.get_default_shop()
-    result = locale.currency(value, grouping=grouping, international=shop.use_international_currency_code)
+    shop = lfs.core.utils.get_default_shop(request)
+    try:
+        result = locale.currency(value, grouping=grouping, international=shop.use_international_currency_code)
+    except ValueError:
+        result = value
+
     # add css class if value is negative
     if value < 0:
         # replace the minus symbol if needed
@@ -453,11 +496,18 @@ def currency(value, grouping=True):
         return mark_safe('<span class="negative">%s</span>' % result)
     return result
 
+
 @register.filter
-def decimal_l10n(value):
+def decimal_l10n(value, digits=2):
     """Returns the decimal value of value based on current locale.
     """
-    return locale.format_string("%.2f", value)
+    try:
+        value = float(value)
+    except ValueError:
+        return value
+
+    format_str = "%%.%sf" % digits
+    return locale.format_string(format_str, value)
 
 
 @register.filter
@@ -531,21 +581,137 @@ def packages(cart_item):
     """Returns the packages based on product's package unit and cart items
     amount.
     """
-    cart_item = cart_item.get("obj")
     if cart_item.product.packing_unit:
-        return int(math.ceil(cart_item.amount / cart_item.product.packing_unit))
+        return int(math.ceil(float(cart_item.amount) / cart_item.product.packing_unit))
     return 0
 
 
+class CategoryProductPricesGrossNode(Node):
+    """
+    Node to calculate needed gross prices of a product for the category view.
+    """
+    def __init__(self, product_id):
+        self.product_id = template.Variable(product_id)
+
+    def render(self, context):
+        request = context.get("request")
+
+        product_id = self.product_id.resolve(context)
+        product = Product.objects.get(pk=product_id)
+
+        if product.is_variant():
+            parent = product.parent
+        else:
+            parent = product
+
+        if parent.category_variant == CATEGORY_VARIANT_CHEAPEST_PRICES:
+            if product.get_for_sale():
+                info = parent.get_cheapest_standard_price_gross(request)
+                context["standard_price"] = info["price"]
+                context["standard_price_starting_from"] = info["starting_from"]
+
+            info = parent.get_cheapest_price_gross(request)
+            context["price"] = info["price"]
+            context["price_starting_from"] = info["starting_from"]
+
+            info = parent.get_cheapest_base_price_gross(request)
+            context["base_price"] = info["price"]
+            context["base_price_starting_from"] = info["starting_from"]
+        else:
+            if product.get_for_sale():
+                context["standard_price"] = product.get_standard_price(request)
+            context["price"] = product.get_price_gross(request)
+            context["price_starting_from"] = False
+
+            context["base_price"] = product.get_base_price_gross(request)
+            context["base_price_starting_from"] = False
+
+        if product.get_active_packing_unit():
+            context["base_packing_price"] = product.get_base_packing_price_gross(request)
+
+        return ""
+
+def do_category_product_prices_gross(parser, token):
+    """
+    Calculates needed gross price of a product for the category view.
+    """
+    bits = token.contents.split()
+    if len(bits) != 2:
+        raise TemplateSyntaxError('%s tag needs product id as argument' % bits[0])
+    return CategoryProductPricesGrossNode(bits[1])
+register.tag('category_product_prices_gross', do_category_product_prices_gross)
+
+
 @register.filter(name='get_price')
-def get_price(product, request):
+def get_price_net(product, request):
     return product.get_price(request)
 
 
+@register.filter(name='get_price_net')
+def get_price_net(product, request):
+    return product.get_price_net(request)
+
+
+@register.filter(name='get_price_gross')
+def get_price_gross(product, request):
+    return product.get_price_gross(request)
+
+
+@register.filter(name='get_standard_price')
+def get_standard_price(product, request):
+    return product.get_standard_price(request)
+
+
+@register.filter(name='get_standard_price_net')
+def get_standard_price_net(product, request):
+    return product.get_standard_price_net(request)
+
+
+@register.filter(name='get_standard_price_gross')
+def get_standard_price_gross(product, request):
+    return product.get_standard_price_gross(request)
+
+
 @register.filter(name='get_for_sale_price')
 def get_for_sale_price(product, request):
     return product.get_for_sale_price(request)
 
-@register.filter(name='get_standard_price')
-def get_standard_price(product, request):
-    return product.get_standard_price(request)
+
+@register.filter(name='get_for_sale_price_net')
+def get_for_sale_price_net(product, request):
+    return product.get_for_sale_price_net(request)
+
+
+@register.filter(name='get_for_sale_price_gross')
+def get_for_sale_price_gross(product, request):
+    return product.get_for_sale_price_gross(request)
+
+
+@register.filter(name='get_base_price')
+def get_base_price(product, request):
+    return product.get_base_price(request)
+
+
+@register.filter(name='get_base_price_net')
+def get_base_price_net(product, request):
+    return product.get_base_price_net(request)
+
+
+@register.filter(name='get_base_price_gross')
+def get_base_price_gross(product, request):
+    return product.get_base_price_gross(request)
+
+
+@register.filter(name='get_base_packing_price')
+def get_base_packing_price(product, request):
+    return product.get_base_packing_price(request)
+
+
+@register.filter(name='get_base_packing_price_net')
+def get_base_packing_price_net(product, request):
+    return product.get_base_packing_price_net(request)
+
+
+@register.filter(name='get_base_packing_price_gross')
+def get_base_packing_price_gross(product, request):
+    return product.get_base_packing_price_gross(request)
