@@ -13,17 +13,19 @@ from lfs.core.models import Shop
 from lfs.core.signals import order_submitted
 from lfs.criteria import utils as criteria_utils
 from lfs.customer import utils as customer_utils
-from lfs.order.settings import PAID
 from lfs.payment.models import PaymentMethod
 from lfs.payment.settings import PAYPAL
+from lfs.payment.settings import PM_ORDER_IMMEDIATELY
+from lfs.payment.settings import PM_ORDER_ACCEPTED
 
 # other imports
 from paypal.standard.conf import POSTBACK_ENDPOINT, SANDBOX_POSTBACK_ENDPOINT
 
 
 def update_to_valid_payment_method(request, customer, save=False):
-    """After this method has been called the given customer has a valid
-    payment method.
+    """
+    After this method has been called the given customer has a valid payment
+    method.
     """
     valid_sms = get_valid_payment_methods(request)
 
@@ -34,7 +36,8 @@ def update_to_valid_payment_method(request, customer, save=False):
 
 
 def get_valid_payment_methods(request):
-    """Returns all valid payment methods (aka. selectable) for given request as
+    """
+    Returns all valid payment methods (aka. selectable) for given request as
     list.
     """
     result = []
@@ -45,14 +48,16 @@ def get_valid_payment_methods(request):
 
 
 def get_default_payment_method(request):
-    """Returns the default payment method for given request.
+    """
+    Returns the default payment method for given request.
     """
     active_payment_methods = PaymentMethod.objects.filter(active=True)
     return criteria_utils.get_first_valid(request, active_payment_methods)
 
 
 def get_selected_payment_method(request):
-    """Returns the selected payment method for given request. This could either
+    """
+    Returns the selected payment method for given request. This could either
     be an explicitly selected payment method of the current user or the default
     payment method.
     """
@@ -64,7 +69,8 @@ def get_selected_payment_method(request):
 
 
 def get_payment_costs(request, payment_method):
-    """Returns the payment price and tax for the given request.
+    """
+    Returns the payment price and tax for the given request.
     """
     if payment_method is None:
         return {
@@ -98,22 +104,38 @@ def get_payment_costs(request, payment_method):
 
 
 def process_payment(request):
-    """Processes the payment depending on the selected payment method. Returns
-    a dictionary with the success state, the next url and a optional error
+    """
+    Processes the payment depending on the selected payment method. Returns a
+    dictionary with the success state, the next url and a optional error
     message.
     """
     payment_method = get_selected_payment_method(request)
-    shop = lfs.core.utils.get_default_shop()
 
     if payment_method.module:
-        module = lfs.core.utils.import_module(payment_method.module + ".views")
-        result = module.process(request)
-        if result["accepted"] == True:
+        payment_class = lfs.core.utils.import_symbol(payment_method.module)
+        payment_instance = payment_class(request)
+
+        create_order_time = payment_instance.get_create_order_time()
+        if create_order_time == PM_ORDER_IMMEDIATELY:
             order = lfs.order.utils.add_order(request)
-            # TODO: this has to be returned from the module
-            order.state = PAID
-            order.save()
+            payment_instance.order = order
+            result = payment_instance.process()
+            if result.get("order_state"):
+                order.state = result.get("order_state")
+                order.save()
             order_submitted.send({"order": order, "request": request})
+        else:
+            cart = lfs.cart.utils.get_cart(request)
+            payment_instance.cart = cart
+            result = payment_instance.process()
+
+        if result["accepted"]:
+            if create_order_time == PM_ORDER_ACCEPTED:
+                order = lfs.order.utils.add_order(request)
+                if result.get("order_state"):
+                    order.state = result.get("order_state")
+                    order.save()
+                order_submitted.send({"order": order, "request": request})
         return result
 
     elif payment_method.id == PAYPAL:
@@ -123,38 +145,24 @@ def process_payment(request):
             if settings.LFS_PAYPAL_REDIRECT:
                 return {
                     "accepted": True,
-                    "next-url": order.get_pay_link(),
+                    "next_url": order.get_pay_link(request),
                 }
         return {
             "accepted": True,
-            "next-url": reverse("lfs_thank_you"),
+            "next_url": reverse("lfs_thank_you"),
         }
     else:
         order = lfs.order.utils.add_order(request)
         order_submitted.send({"order": order, "request": request})
         return {
             "accepted": True,
-            "next-url": reverse("lfs_thank_you"),
+            "next_url": reverse("lfs_thank_you"),
         }
 
 
-def get_next_url(payment_method, order):
-    """Creates the next url for the passed payment method and order.
+def get_pay_link(request, payment_method, order):
     """
-    if payment_method.id == PAYPAL:
-        return get_paypal_link_for_order(order)
-    elif payment_method.module:
-        module = lfs.core.utils.import_module.import_module(payment_method + ".views")
-        try:
-            return module.get_next_url(order)
-        except AttributeError:
-            return None
-    else:
-        return None
-
-
-def get_pay_link(payment_method, order):
-    """Creates a pay link for the passed payment_method and order.
+    Creates a pay link for the passed payment_method and order.
 
     This can be used to display the link within the order mail and/or the
     thank you page after a customer has payed.
@@ -162,9 +170,10 @@ def get_pay_link(payment_method, order):
     if payment_method.id == PAYPAL:
         return get_paypal_link_for_order(order)
     elif payment_method.module:
-        module = lfs.core.utils.import_module(payment_method.module + ".views")
+        payment_class = lfs.core.utils.import_symbol(payment_method.module)
+        payment_instance = payment_class(request=request, order=order)
         try:
-            return module.get_pay_link(order)
+            return payment_instance.get_pay_link()
         except AttributeError:
             return ""
     else:
@@ -172,11 +181,12 @@ def get_pay_link(payment_method, order):
 
 
 def get_paypal_link_for_order(order):
-    """Creates paypal link for given order.
+    """
+    Creates paypal link for given order.
     """
     shop = lfs_get_object_or_404(Shop, pk=1)
     current_site = Site.objects.get(id=settings.SITE_ID)
-    conv=locale.localeconv()
+    conv = locale.localeconv()
     default_currency = conv['int_curr_symbol']
 
     info = {
